/******************************************************************
*
* Licensed Materials - Property of IBM
*
* (C) Copyright IBM Corp. 2018, 2018. All Rights Reserved.
*
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*
*******************************************************************
*/

/// \file ddl_mpi.hpp
/// \brief IBM Distributed Deep Learning Library with MPI

#ifndef _DDL_MPI_HPP_
#define _DDL_MPI_HPP_

#include <mpi.h>

extern "C" {

/// Call DDL's allreduce within an MPI program
/// ddl_init does not need to be called before using ddl_allreduce_mpi
/// \param options contains a string of options for DDL. If ddl_init was previously called
///        options will be ignored
/// \param buffer points to an array of data
/// \param n is the number of elements in buffer
/// \param datatype is the datatype of buffer. The supported MPI_Datatypes are: MPI_FLOAT and
///        MPI_SHORT, where MPI_SHORT is used to represent 16-bit floating point numbers
/// \param op is the reduction operation to perform. The only supported MPI_Op is MPI_SUM
/// \param comm is is the MPI communicator. The only supported MPI_Comm is MPI_COMM_WORLD
/// \return The result status
int ddl_allreduce_mpi(const char* options, void* buffer, int n, MPI_Datatype datatype, MPI_Op op, MPI_Comm comm);
}

#endif
